@@ -1143,26 +1143,55 @@ QColor Svg::color(StyleSheetColor colorName) const
 
 void Svg::setColor(StyleSheetColor colorName, const QColor &color)
 {
-    if (d->colorOverrides.value(colorName) == color) {
+    setColors({
+        {colorName, color},
+    });
+}
+
+void Svg::setColors(const QMap<StyleSheetColor, QColor> &colors)
+{
+    bool changed = false;
+    for (const auto &[colorName, color] : colors.asKeyValueRange()) {
+        if (d->colorOverrides.value(colorName) != color) {
+            changed = true;
+
+            if (color.isValid()) {
+                d->colorOverrides[colorName] = color;
+            } else {
+                d->colorOverrides.remove(colorName);
+            }
+        }
+    }
+
+    if (!changed) {
         return;
     }
 
-    if (color.isValid()) {
-        d->colorOverrides[colorName] = color;
-    } else {
-        d->colorOverrides.remove(colorName);
-    }
     d->stylesheetOverride.clear();
 
     d->eraseRenderer();
+
+    // Ideally, there should be a signal but adding a new signal can make ksvg users crash in QML cache code.
+    if (auto frameSvg = qobject_cast<FrameSvg *>(this)) {
+        frameSvg->colorOverridesChange();
+    }
+
     Q_EMIT repaintNeeded();
 }
 
+QMap<Svg::StyleSheetColor, QColor> Svg::colorOverrides() const
+{
+    return d->colorOverrides;
+}
+
 void Svg::clearColorOverrides()
 {
     d->colorOverrides.clear();
     d->stylesheetOverride.clear();
     d->eraseRenderer();
+    if (auto frameSvg = qobject_cast<FrameSvg *>(this)) {
+        frameSvg->colorOverridesChange();
+    }
     Q_EMIT repaintNeeded();
 }
 
